cli

package
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 6, 2026 License: MIT Imports: 15 Imported by: 0

Documentation

Overview

Package cli defines Cobra commands for the agent-factory CLI. Commands contain only flag parsing and delegate to command-specific packages.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute runs the root command.

func NewRootCommand

func NewRootCommand() *cobra.Command

NewRootCommand creates the top-level Cobra command for the infinite-you CLI.

Types

This section is empty.

Directories

Path Synopsis
Package config implements agent-factory config command behavior.
Package config implements agent-factory config command behavior.
Package dashboard provides read models and pretty-print rendering for the factory dashboard.
Package dashboard provides read models and pretty-print rendering for the factory dashboard.
Package defaultcmd defines the no-argument agent-factory default flow.
Package defaultcmd defines the no-argument agent-factory default flow.
Package docs provides the packaged markdown reference topics exposed by the agent-factory CLI docs surface.
Package docs provides the packaged markdown reference topics exposed by the agent-factory CLI docs surface.
Package initcmd implements the agent-factory init command behavior.
Package initcmd implements the agent-factory init command behavior.
Package run implements the agent-factory run command behavior.
Package run implements the agent-factory run command behavior.
Package submit implements agent-factory submit command behavior.
Package submit implements agent-factory submit command behavior.

Jump to