docs

package
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 4, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package docs provides the packaged markdown reference topics exposed by the agent-factory CLI docs surface.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Markdown

func Markdown(topic string) (string, error)

Markdown returns the embedded markdown page for one supported topic.

func SupportedTopics

func SupportedTopics() []string

SupportedTopics returns the fixed docs topics exposed by the packaged CLI docs surface in display order.

Types

type Topic

type Topic string

Topic is one stable docs topic name exposed by the CLI.

const (
	TopicConfig      Topic = "config"
	TopicWorkstation Topic = "workstation"
	TopicWorkers     Topic = "workers"
	TopicResources   Topic = "resources"
	TopicBatchWork   Topic = "batch-work"
	TopicTemplates   Topic = "templates"
)

Jump to