package
Version:
v0.0.2
Opens a new window with list of versions in this module.
Published: May 4, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package docs provides the packaged markdown reference topics exposed by the
agent-factory CLI docs surface.
Markdown returns the embedded markdown page for one supported topic.
func SupportedTopics() []string
SupportedTopics returns the fixed docs topics exposed by the packaged CLI
docs surface in display order.
Topic is one stable docs topic name exposed by the CLI.
const (
TopicConfig Topic = "config"
TopicWorkstation Topic = "workstation"
TopicWorkers Topic = "workers"
TopicResources Topic = "resources"
TopicBatchWork Topic = "batch-work"
TopicTemplates Topic = "templates"
)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.